@@ -582,12 +582,6 @@ freq <- function(..., data = NULL, print = c("no", "all", "perc", "v.perc"),
 
   class(object) <- "misty.object"
 
-  #_____________________________________________________________________________
-  #
-  # Write results --------------------------------------------------------------
-
-  if (isTRUE(!is.null(write))) { misty::write.result(object, file = write) }
-
   #_____________________________________________________________________________
   #
   # Output ---------------------------------------------------------------------
